@@ -7,6 +7,9 @@
 #include "kconstants.h"
 
 #include <QDesktopServices>
+#ifdef Q_OS_WIN
+#include <QtPlatformHeaders\QWindowsWindowFunctions>
+#endif
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -38,6 +41,13 @@ MainWindow::MainWindow(QWidget *parent) :
 #if !SYSTEMTITLEBAR
     setWindowFlags(Qt::Window | Qt::CustomizeWindowHint);
 #endif
+#ifdef Q_OS_WIN
+    QWindow *window = windowHandle();
+    if (!window) {
+        return;
+    }
+    QWindowsWindowFunctions::setHasBorderInFullScreen(window, true);
+#endif
 }
 
 MainWindow::~MainWindow()
@@ -70,4 +80,4 @@ QStackedWidget *MainWindow::getSideDockWidget()
 ContentManagerSide *MainWindow::getSideContentManager()
 {
     return mp_ui->contentmanagerside;
-}
+}
\ No newline at end of file
